==> seedsui-react-5.8.10.tgz: package/lib/Layout/Main/Bottom.js <==
var _excluded = ["children", "caption", "type"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import locale from "./../../locale";

// type: loading,noMore,failed
var BottomFinish = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var children = _ref.children,
    caption = _ref.caption,
    type = _ref.type,
    props = _objectWithoutProperties(_ref, _excluded);
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });

  // 获取提示
  function getCaption() {
    if (caption) return caption;
    if (type === 'loading') {
      return /*#__PURE__*/React.createElement("div", {
        className: "layout-main-pull-push-wrapper"
      }, /*#__PURE__*/React.createElement("div", {
        className: "layout-main-pull-push-icon layout-main-pull-push-icon-loading"
      }), /*#__PURE__*/React.createElement("div", {
        className: "layout-main-pull-push-caption"
      }, locale('正在加载...', 'loading')));
    } else {
      return /*#__PURE__*/React.createElement("div", {
        className: "layout-main-pull-push-wrapper"
      }, /*#__PURE__*/React.createElement("div", {
        className: "layout-main-pull-push-caption"
      }, type === 'noMore' ? locale('没有更多数据了', 'no_more_data') : locale('加载失败, 请稍后再试', 'loading_failed')));
    }
  }
  return /*#__PURE__*/React.createElement("div", _extends({
    className: "SID-Dragrefresh-ErrorContainer layout-main-pull-push",
    style: {
      height: '50px'
    }
  }, props, {
    ref: rootRef
  }), !children && getCaption(), children);
});
export default BottomFinish;

==> seedsui-react-5.8.44.tgz: package/lib/Layout/Main/Bottom.js <==
var _excluded = ["children", "caption", "type"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import locale from "./../../locale";

// type: loading,noMore,failed
var BottomFinish = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var children = _ref.children,
    caption = _ref.caption,
    type = _ref.type,
    props = _objectWithoutProperties(_ref, _excluded);
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });

  // 获取提示
  function getCaption() {
    if (caption) return caption;
    if (type === 'loading') {
      return /*#__PURE__*/React.createElement("div", {
        className: "layout-main-pull-push-wrapper"
      }, /*#__PURE__*/React.createElement("div", {
        className: "layout-main-pull-push-icon layout-main-pull-push-icon-loading"
      }), /*#__PURE__*/React.createElement("div", {
        className: "layout-main-pull-push-caption"
      }, locale('正在加载...', 'SeedsUI_loading')));
    } else {
      return /*#__PURE__*/React.createElement("div", {
        className: "layout-main-pull-push-wrapper"
      }, /*#__PURE__*/React.createElement("div", {
        className: "layout-main-pull-push-caption"
      }, type === 'noMore' ? locale('没有更多数据了', 'SeedsUI_no_more_data') : locale('加载失败, 请稍后再试', 'SeedsUI_load_failed')));
    }
  }
  return /*#__PURE__*/React.createElement("div", _extends({
    className: "SID-Dragrefresh-ErrorContainer layout-main-pull-push",
    style: {
      height: '50px'
    }
  }, props, {
    ref: rootRef
  }), !children && getCaption(), children);
});
export default BottomFinish;
